@@ -5,12 +5,12 @@
 Language
 </category>
 
-<name>  
+<name>
 Hungarian
 </name>
 
 <description>  
-Hungarian Language Meta-Package
+Hungarian dictionary for hunspell
 </description>
 
 <installable>
@@ -25,9 +25,7 @@ echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
-aspell-hu
-myspell-hu
-manpages-hu
+hunspell-hu
 </install_package_names>
 
 <postinstall>
@@ -35,9 +33,7 @@ manpages-hu
 </postinstall>
 
 <uninstall_package_names>
-aspell-hu
-myspell-hu
-manpages-hu
+hunspell-hu
 </uninstall_package_names>
 
 </app>
